@@ -15,12 +15,21 @@ logging.basicConfig(
 )
 
 
-def set_token_session(app, verify, per_defaults: list):
+def set_token_session(app, verify, per_defaults: list, whitelist: list = []):
     app.secret_key = 'sdfj48@$NF94@4dfsdf&)$#*'  # 配置session key
 
     @app.before_request
     def base_auth():
         """验证用户是否有访问页面的权限"""
+        for path in whitelist:
+            request_path = request.path
+            path_list = path.split('/<')
+            if len(path_list) != 1:
+                path = path_list[0]
+                request_path = '/'.join(request_path.split('/')[:-1])
+            if request_path == path:
+                return  # 忽略路由白名单列表中的路由认证
+        # 调用VerifyToken类进行校验
         user = verify.verify_token(request)
         session['token_id'] = user['token_id']
         session['user_name'] = user['user_name']
